You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by da...@apache.org on 2005/12/02 06:14:51 UTC

svn commit: r351594 [2/5] - in /webservices/axis2/trunk/c: ./ ides/anjuta/ include/ modules/core/context/src/ modules/core/description/src/ modules/core/engine/src/ modules/core/phaseresolver/src/ modules/core/phaseresolver/src/.deps/ modules/core/tran...

Modified: webservices/axis2/trunk/c/include/axis2_svc_grp.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_svc_grp.h?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_svc_grp.h (original)
+++ webservices/axis2/trunk/c/include/axis2_svc_grp.h Thu Dec  1 21:13:39 2005
@@ -36,7 +36,7 @@
   * @{
   */
 
-struct axis2_svc_s;
+struct axis2_svc;
 typedef struct axis2_svc_grp_ops axis2_svc_grp_ops_t;    
 typedef struct axis2_svc_grp axis2_svc_grp_t;
     
@@ -50,59 +50,87 @@
      * Deallocate memory
      * @return status code
      */
-    axis2_status_t (AXIS2_CALL *free) (axis2_svc_grp_t *svc_grp, 
-                                        axis2_env_t **env);
+    axis2_status_t (AXIS2_CALL *
+    free) (axis2_svc_grp_t *svc_grp, 
+           axis2_env_t **env);
     
     /** 
      * Set name of the service group
      * @param svc_grp_name service group name
      * @return status_code
      */
-    axis2_status_t (AXIS2_CALL *set_name) (axis2_svc_grp_t *svc_grp, 
-                                            axis2_env_t **env, 
-                                            axis2_char_t *svc_grp_name);
+    axis2_status_t (AXIS2_CALL *
+    set_name) (axis2_svc_grp_t *svc_grp, 
+                axis2_env_t **env, 
+                axis2_char_t *svc_grp_name);
 	/** 
      * Get the service group name
      * @return service group name
      */
-    axis2_char_t *(AXIS2_CALL *get_name) (axis2_svc_grp_t *svc_grp, 
-                                            axis2_env_t **env) ;
+    axis2_char_t *(AXIS2_CALL *
+    get_name) (axis2_svc_grp_t *svc_grp, 
+               axis2_env_t **env) ;
     /** 
      * Add a service to the serivce group
      * @param service service to be added
      * @return status code
      */
-	axis2_status_t (AXIS2_CALL *add_svc) (axis2_svc_grp_t *svc_grp, 
-                                            axis2_env_t **env,
-	 	                                    struct axis2_svc_s *svc) ;
+	axis2_status_t (AXIS2_CALL *
+    add_svc) (axis2_svc_grp_t *svc_grp, 
+                axis2_env_t **env,
+                struct axis2_svc *svc) ;
     
     /** 
      * Get the service from service group
      * @param svc_name name of the service
      * @return service description
      */
-	struct axis2_svc_s *(AXIS2_CALL *get_svc) (axis2_svc_grp_t *svc_grp, 
-                                                axis2_env_t **env,
-	                                            const axis2_qname_t *svc_name);
-        
-	axis2_status_t (AXIS2_CALL *remove_svc) (axis2_svc_grp_t *svc_grp, 
-                                             axis2_env_t **env,
-		                                     const axis2_qname_t *svc_name);
+	struct axis2_svc *(AXIS2_CALL *
+    get_svc) (axis2_svc_grp_t *svc_grp, 
+                axis2_env_t **env,
+                axis2_qname_t *svc_name);
+    
+    axis2_hash_t *(AXIS2_CALL *
+    get_svcs) (axis2_svc_grp_t *svc_grp, 
+               axis2_env_t **env);
+    
+	axis2_status_t (AXIS2_CALL *
+    remove_svc) (axis2_svc_grp_t *svc_grp, 
+                 axis2_env_t **env,
+                 axis2_qname_t *svc_name);
         
-	axis2_status_t (AXIS2_CALL *add_param) (axis2_svc_grp_t *svc_grp, 
-                                                axis2_env_t **env, 
-                                                axis2_param_t *param);
+	axis2_status_t (AXIS2_CALL *
+    add_param) (axis2_svc_grp_t *svc_grp, 
+                axis2_env_t **env, 
+                axis2_param_t *param);
         
-	axis2_param_t *(AXIS2_CALL *get_param) (axis2_svc_grp_t *svc_grp, 
-                                                axis2_env_t **env, 
-                                                const axis2_char_t *name);
+	axis2_param_t *(AXIS2_CALL *
+    get_param) (axis2_svc_grp_t *svc_grp, 
+                axis2_env_t **env, 
+                const axis2_char_t *name);
         
-	axis2_hash_t *(AXIS2_CALL *get_params) (axis2_svc_grp_t *svc_grp, 
-                                                axis2_env_t **env);
+	axis2_array_list_t *(AXIS2_CALL *
+    get_params) (axis2_svc_grp_t *svc_grp, 
+                 axis2_env_t **env);
+    
+	axis2_bool_t (AXIS2_CALL *
+    is_param_locked) (axis2_svc_grp_t *svc_grp, 
+                        axis2_env_t **env, 
+                        axis2_char_t *param_name);
+                        
+    axis2_status_t (AXIS2_CALL *
+    add_module) (axis2_svc_grp_t *svc_grp, 
+                    axis2_env_t **env,
+                    axis2_qname_t *module_qname);
+
+    struct axis2_engine_config * (AXIS2_CALL *
+    get_parent) (axis2_svc_grp_t *svc_grp,
+                    axis2_env_t **env);
     
-	axis2_bool_t (AXIS2_CALL *is_param_locked) (axis2_svc_grp_t *svc_grp, 
-                                                axis2_env_t **env, 
-                                                const axis2_char_t *param_name);
+    axis2_status_t (AXIS2_CALL *
+    set_parent) (axis2_svc_grp_t *svc_grp,
+                    axis2_env_t **env,
+                    struct axis2_engine_config *parent);
 };
 
 /** 
@@ -111,7 +139,8 @@
  */
 struct axis2_svc_grp
 {
-	axis2_svc_grp_ops_t *ops;   
+	axis2_svc_grp_ops_t *ops; 
+    axis2_param_container_t *param_container;    
 
 };
 
@@ -122,37 +151,57 @@
 AXIS2_DECLARE(axis2_svc_grp_t *)
 axis2_svc_grp_create (axis2_env_t **env);
 
+/** 
+ * Creates service group struct
+ * @param engine_config
+ * @return pointer to newly created service group
+ */
+axis2_svc_grp_t * AXIS2_CALL 
+axis2_svc_grp_create_with_engine_config (axis2_env_t **env,
+                                         struct axis2_engine_config *engine_config);
+
 /**************************** Start of function macros ************************/
 
-#define AXIS2_SVC_GRP_FREE(svc_grp, env) (svc_grp->ops->free (svc_grp , env));
+#define AXIS2_SVC_GRP_FREE(svc_grp, env) (svc_grp->ops->free (svc_grp , env))
 	
 #define AXIS2_SVC_GRP_SET_NAME(svc_grp, env , svc_grp_name) \
-        (svc_grp->ops->set_name (svc_grp, env, svc_grp_name));
+        (svc_grp->ops->set_name (svc_grp, env, svc_grp_name))
 		
 #define AXIS2_SVC_GRP_GET_NAME(svc_grp, env) \
-        (svc_grp->ops->get_name(svc_grp, env));
+        (svc_grp->ops->get_name(svc_grp, env))
 
 #define AXIS2_SVC_GRP_ADD_SVC(svc_grp, env , svc) \
-        (svc_grp->ops->add_svc (svc_grp, env, svc));
+        (svc_grp->ops->add_svc (svc_grp, env, svc))
 
 #define AXIS2_SVC_GRP_GET_SVC(svc_grp, env , svc) \
-        (svc_grp->ops->get_svc(svc_grp, env, svc));
-		
+        (svc_grp->ops->get_svc(svc_grp, env, svc))
+
+#define AXIS2_SVC_GRP_GET_SVCS(svc_grp, env) \
+        (svc_grp->ops->get_svcs(svc_grp, env))
+        
 #define AXIS2_SVC_GRP_REMOVE_SVC(svc_grp, env, srvc_name) \
-		(svc_grp->ops->remove_svc(svc_grp, env, srvc_name));		
+		(svc_grp->ops->remove_svc(svc_grp, env, srvc_name))		
 
 #define AXIS2_SVC_GRP_ADD_PARAM(svc_grp, env, param) \
-		(svc_grp->ops->add_param(svc_grp, env, param));
+		(svc_grp->ops->add_param(svc_grp, env, param))
 		
 #define AXIS2_SVC_GRP_GET_PARAM(svc_grp, env, name) \
-		(svc_grp->ops->get_param(svc_grp, env, name));
+		(svc_grp->ops->get_param(svc_grp, env, name))
 		
 #define AXIS2_SVC_GRP_GET_PARAMS(svc_grp, env) \
-        (svc_grp->ops->get_params(svc_grp, env));
+        (svc_grp->ops->get_params(svc_grp, env))
 				
 #define AXIS2_SVC_GRP_IS_PARAM_LOCKED(svc_grp, env , param_name) \
-        (svc_grp->ops->is_param_locked(svc_grp, env, param_name));
+        (svc_grp->ops->is_param_locked(svc_grp, env, param_name))
+
+#define AXIS2_SVC_GRP_ADD_MODULE(svc_grp, env , module_qname) \
+        (svc_grp->ops->add_module(svc_grp, env, module_qname))
+
+#define AXIS2_SVC_GRP_GET_PARENT(svc_grp, env) \
+        (svc_grp->ops->get_parent(svc_grp, env))
         
+#define AXIS2_SVC_GRP_SET_PARENT(svc_grp, env , parent) \
+        (svc_grp->ops->set_parent(svc_grp, env, parent))        
 /**************************** End of function macros **************************/        
 
 /** @} */

Modified: webservices/axis2/trunk/c/include/axis2_transport_in_desc.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_transport_in_desc.h?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_transport_in_desc.h (original)
+++ webservices/axis2/trunk/c/include/axis2_transport_in_desc.h Thu Dec  1 21:13:39 2005
@@ -33,7 +33,7 @@
 #include <axis2_phase_meta.h>
 #include <axis2_phase.h>
 #include <axis2_flow.h>
-#include <wsdl.h>
+#include <axis2_wsdl.h>
 
 #ifdef __cplusplus
 extern "C"
@@ -153,14 +153,14 @@
 #define AXIS2_TRANSPORT_IN_DESC_FREE(transport_in_desc, env) \
 		((transport_in_desc->ops)->free (transport_in_desc, env))
 
-#define AXIS2_TRANSPORT_IN_DESC_GET_QNAME(transport_in_desc, env, phase_name) \
-		((transport_in_desc->ops)->get_qname (transport_in_desc, env, phase_name))
+#define AXIS2_TRANSPORT_IN_DESC_GET_QNAME(transport_in_desc, env) \
+		((transport_in_desc->ops)->get_qname (transport_in_desc, env))
 
-#define AXIS2_TRANSPORT_IN_DESC_SET_QNAME(transport_in_desc, env, handler, qname) \
-		((transport_in_desc->ops)->set_qname (transport_in_desc, env, handler, qname))
+#define AXIS2_TRANSPORT_IN_DESC_SET_QNAME(transport_in_desc, env, qname) \
+		((transport_in_desc->ops)->set_qname (transport_in_desc, env, qname))
 
-#define AXIS2_TRANSPORT_IN_DESC_GET_INFLOW(transport_in_desc, env, phase_name) \
-		((transport_in_desc->ops)->get_inflow (transport_in_desc, env, phase_name))
+#define AXIS2_TRANSPORT_IN_DESC_GET_INFLOW(transport_in_desc, env) \
+		((transport_in_desc->ops)->get_inflow (transport_in_desc, env))
 
 #define AXIS2_TRANSPORT_IN_DESC_SET_INFLOW(transport_in_desc, env, inflow) \
 		((transport_in_desc->ops)->set_inflow (transport_in_desc, env, inflow))       

Modified: webservices/axis2/trunk/c/include/axis2_transport_out_desc.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_transport_out_desc.h?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_transport_out_desc.h (original)
+++ webservices/axis2/trunk/c/include/axis2_transport_out_desc.h Thu Dec  1 21:13:39 2005
@@ -0,0 +1,199 @@
+/*
+ * Copyright 2004,2005 The Apache Software Foundation.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+#ifndef AXIS2_TRANSPORT_OUT_DESC_H
+#define AXIS2_TRANSPORT_OUT_DESC_H
+
+/**
+ * @file axis2_transport_out_desc.h
+ * @brief Axis2 description transport out interface
+ */
+
+#include <axis2.h>
+#include <axis2_error.h>
+#include <axis2_defines.h>
+#include <axis2_env.h>
+#include <axis2_allocator.h>
+#include <axis2_qname.h>
+#include <axis2_array_list.h>
+#include <axis2_transport_sender.h>
+#include <axis2_phase_meta.h>
+#include <axis2_phase.h>
+#include <axis2_flow.h>
+#include <axis2_wsdl.h>
+
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
+struct axis2_phase;
+struct axis2_transport_sender;    
+typedef struct axis2_transport_out_desc axis2_transport_out_desc_t;
+typedef struct axis2_transport_out_desc_ops axis2_transport_out_desc_ops_t;
+
+/** @defgroup axis2_transport_out_desc Transport in
+ * @ingroup axis2_descriptions
+ * @{
+ */
+
+/** 
+ * @brief Description Transport Out operations struct
+ * Encapsulator struct for operations of axis2_transport_out_desc
+ */
+AXIS2_DECLARE_DATA struct axis2_transport_out_desc_ops
+{
+	/** De-allocate memory
+  	 * @return status code
+  	 */
+	axis2_status_t (AXIS2_CALL *free)(
+                    axis2_transport_out_desc_t *transport_out_desc,
+			        axis2_env_t **env);
+    
+    /**
+     * @return
+     */
+    axis2_qname_t *(AXIS2_CALL *
+    get_qname) (struct axis2_transport_out_desc *transport_out,
+                                            axis2_env_t **env);
+    
+    /**
+     * @param name
+     */
+    axis2_status_t (AXIS2_CALL *
+    set_qname) (struct axis2_transport_out_desc *transport_out,
+                                            axis2_env_t **env,
+                                            axis2_qname_t *qname);
+    
+    struct axis2_flow *(AXIS2_CALL *
+    get_outflow) (struct axis2_transport_out_desc *transport_out,
+                                            axis2_env_t **env);
+    
+    axis2_status_t (AXIS2_CALL *
+    set_outflow) (struct axis2_transport_out_desc *transport_out,
+                                            axis2_env_t **env,
+                                            struct axis2_flow *outflow);
+    
+    struct axis2_flow *(AXIS2_CALL *
+    get_faultflow) (struct axis2_transport_out_desc *transport_out,
+                                            axis2_env_t **env);
+    
+    axis2_status_t (AXIS2_CALL *
+    set_faultflow) (struct axis2_transport_out_desc *transport_out,
+                                            axis2_env_t **env,
+                                            struct axis2_flow *faultflow);
+    
+    /**
+     * @return
+     */
+    struct axis2_transport_sender * (AXIS2_CALL *
+    get_sender) (struct axis2_transport_out_desc *transport_out,
+                                            axis2_env_t **env);
+    
+    /**
+     * @param receiver
+     */
+    axis2_status_t (AXIS2_CALL *
+    set_sender) (struct axis2_transport_out_desc *transport_out,
+                                            axis2_env_t **env,
+                                            struct axis2_transport_sender *sender);
+    
+    struct axis2_phase * (AXIS2_CALL *
+    get_outphase) (struct axis2_transport_out_desc *transport_out,
+                                            axis2_env_t **env);
+    
+    axis2_status_t (AXIS2_CALL *
+    set_outphase) (struct axis2_transport_out_desc *transport_out,
+                                            axis2_env_t **env,
+                                            struct axis2_phase *outphase);
+    
+    struct axis2_phase *(AXIS2_CALL *
+    get_faultphase) (struct axis2_transport_out_desc *transport_out,
+                                            axis2_env_t **env);
+    
+    axis2_status_t (AXIS2_CALL *
+    set_faultphase) (struct axis2_transport_out_desc *transport_out,
+                                            axis2_env_t **env,
+                                            struct axis2_phase *faultphase);
+        
+
+};
+
+/** 
+ * @brief Transport Out struct  
+ */  
+AXIS2_DECLARE_DATA struct axis2_transport_out_desc
+{
+	axis2_transport_out_desc_ops_t *ops;
+    axis2_param_container_t *param_container;
+};
+
+/**
+ * Creates transport out struct
+ * @return pointer to newly created transport out
+ */
+AXIS2_DECLARE(axis2_transport_out_desc_t *) 
+axis2_transport_out_desc_create_with_qname (axis2_env_t **env, axis2_qname_t *qname);
+
+/*************************** Function macros **********************************/
+
+#define AXIS2_TRANSPORT_OUT_DESC_FREE(transport_out_desc, env) \
+		((transport_out_desc->ops)->free (transport_out_desc, env))
+
+#define AXIS2_TRANSPORT_OUT_DESC_GET_QNAME(transport_out_desc, env) \
+		((transport_out_desc->ops)->get_qname (transport_out_desc, env))
+
+#define AXIS2_TRANSPORT_OUT_DESC_SET_QNAME(transport_out_desc, env, qname) \
+		((transport_out_desc->ops)->set_qname (transport_out_desc, env, qname))
+
+#define AXIS2_TRANSPORT_OUT_DESC_GET_OUTFLOW(transport_out_desc, env) \
+		((transport_out_desc->ops)->get_outflow (transport_out_desc, env))
+
+#define AXIS2_TRANSPORT_OUT_DESC_SET_OUTFLOW(transport_out_desc, env, outflow) \
+		((transport_out_desc->ops)->set_outflow (transport_out_desc, env, outflow))       
+
+#define AXIS2_TRANSPORT_OUT_DESC_GET_FAULTFLOW(transport_out_desc, env) \
+		((transport_out_desc->ops)->get_faultflow (transport_out_desc, env)) 
+        
+#define AXIS2_TRANSPORT_OUT_DESC_SET_FAULTFLOW(transport_out_desc, env, faultflow) \
+		((transport_out_desc->ops)->set_faultflow (transport_out_desc, env, faultflow)) 
+
+#define AXIS2_TRANSPORT_OUT_DESC_GET_SENDER(transport_out_desc, env) \
+		((transport_out_desc->ops)->get_sender (transport_out_desc, env)) 
+        
+#define AXIS2_TRANSPORT_OUT_DESC_SET_SENDER(transport_out_desc, env, sender) \
+		((transport_out_desc->ops)->set_sender (transport_out_desc, env, sender)) 
+
+#define AXIS2_TRANSPORT_OUT_DESC_GET_OUTPHASE(transport_out_desc, env) \
+		((transport_out_desc->ops)->get_outphase (transport_out_desc, env)) 
+        
+#define AXIS2_TRANSPORT_OUT_DESC_SET_OUTPHASE(transport_out_desc, env, outphase) \
+		((transport_out_desc->ops)->set_outphase (transport_out_desc, env, outphase)) 
+
+#define AXIS2_TRANSPORT_OUT_DESC_GET_FAULTPHASE(transport_out_desc, env) \
+		((transport_out_desc->ops)->get_faultphase (transport_out_desc, env)) 
+        
+#define AXIS2_TRANSPORT_OUT_DESC_SET_FAULTPHASE(transport_out_desc, env, faultphase) \
+		((transport_out_desc->ops)->set_faultphase (transport_out_desc, env, faultphase))
+
+/*************************** End of function macros ***************************/
+
+/** @} */
+
+#ifdef __cplusplus
+}
+#endif
+#endif  /* AXIS2_TRANSPORT_OUT_DESC_H */

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_binding_operation.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_binding_operation.h?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_binding_operation.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_binding_operation.h Thu Dec  1 21:13:39 2005
@@ -71,7 +71,7 @@
      *
      * @return operation
      */
-    struct axis2_wsdl_operation *(AXIS2_CALL *
+    void *(AXIS2_CALL *
     get_operation) (axis2_wsdl_binding_operation_t *binding_operation,
                                         axis2_env_t **env);
     
@@ -83,7 +83,7 @@
     axis2_status_t (AXIS2_CALL *
     set_operation)(axis2_wsdl_binding_operation_t *binding_operation,
                                                 axis2_env_t **env,
-                                                struct axis2_wsdl_operation *operation);
+                                                void *operation);
     
     /**
      * Method getOutput

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_component.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_component.h?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_component.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_component.h Thu Dec  1 21:13:39 2005
@@ -12,12 +12,15 @@
 #include <axis2_allocator.h>
 #include <axis2_string.h>
 #include <axis2_hash.h>
+#include <axis2_linked_list.h>
+#include <axis2_wsdl_extensible_element.h>
 
 #ifdef __cplusplus
 extern "C"
 {
 #endif
-	
+
+struct axis2_wsdl_extensible_element;	
 typedef struct axis2_wsdl_component_ops axis2_wsdl_component_ops_t;
 typedef struct axis2_wsdl_component axis2_wsdl_component_t;
 	
@@ -77,7 +80,28 @@
                                         (axis2_wsdl_component_t *wsdl_component, 
                                             axis2_env_t **env,
                                             const void *key);
-    
+ 
+
+
+/**
+ * Adds the <code>Element</code> to this Component.
+ *
+ * @param element
+ */
+axis2_status_t (AXIS2_CALL *
+add_extensibility_element) (axis2_wsdl_component_t *wsdl_component,
+                            axis2_env_t **env,
+                            void *element);
+                                                    
+/**
+ * Returns the Extensibility Elements of this component;
+ *
+ * @return List of <code>Element</code> s
+ */
+axis2_linked_list_t *(AXIS2_CALL *
+get_extensibility_elements) (axis2_wsdl_component_t *wsdl_component,
+                                                axis2_env_t **env);
+                                                
 };
 
 /**
@@ -116,7 +140,14 @@
 		
 #define AXIS2_WSDL_COMPONENT_GET_COMPONENT_PROPERTY(wsdl_component, env, key) \
 		((wsdl_component->ops)->get_component_property(wsdl_component, env, key))
-		
+
+
+#define AXIS2_WSDL_COMPONENT_ADD_EXTENSIBILITY_ELEMENT(wsdl_component, env, element) \
+		((wsdl_component->ops)->add_extensibility_element(wsdl_component, env, element))
+ 
+#define AXIS2_WSDL_COMPONENT_GET_EXTENSIBILITY_ELEMENTS(wsdl_component, env) \
+		((wsdl_component->ops)->get_extensibility_elements(wsdl_component, env))
+        
 /**************************** End of function macros **************************/
 
 /** @} */

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_interface.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_interface.h?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_interface.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_interface.h Thu Dec  1 21:13:39 2005
@@ -98,7 +98,7 @@
      * @param nCName
      * @return
      */
-    struct axis2_operation *(AXIS2_CALL *
+    void *(AXIS2_CALL *
     get_operation) (axis2_wsdl_interface_t *wsdl_interface,
                                     axis2_env_t **env,
                                     axis2_char_t *nc_name);
@@ -165,7 +165,7 @@
     axis2_status_t (AXIS2_CALL *
     set_operation) (axis2_wsdl_interface_t *wsdl_interface,
                                         axis2_env_t **env,
-                                        struct axis2_operation *operation);
+                                        void *operation);
     
     /**
      * @param list
@@ -238,8 +238,11 @@
 #define AXIS2_WSDL_INTERFACE_GET_NAME(wsdl_interface, env) \
 		((wsdl_interface->ops)->get_name (wsdl_interface, env))
 
-#define AXIS2_WSDL_INTERFACE_GET_OPERATIONS(wsdl_interface, env, name) \
-		((wsdl_interface->ops)->get_operations (wsdl_interface, env, name))
+#define AXIS2_WSDL_INTERFACE_GET_OPERATIONS(wsdl_interface, env) \
+		((wsdl_interface->ops)->get_operations (wsdl_interface, env))
+
+#define AXIS2_WSDL_INTERFACE_GET_OPERATION(wsdl_interface, env, nc_name) \
+		((wsdl_interface->ops)->get_operation (wsdl_interface, env, nc_name))
         
 #define AXIS2_WSDL_INTERFACE_GET_SUPER_INTERFACES(wsdl_interface, env) \
 		((wsdl_interface->ops)->get_super_interfaces (wsdl_interface, env))

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_svc.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_svc.h?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_svc.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_svc.h Thu Dec  1 21:13:39 2005
@@ -186,8 +186,8 @@
 #define AXIS2_WSDL_SVC_SET_ENDPOINT(wsdl_svc, env, endpoint) \
         ((wsdl_svc->ops)->set_endpoint(wsdl_svc, env, endpoint))
 
-#define AXIS2_WSDL_SVC_GET_ENDPOINT(wsdl_svc, env) \
-        ((wsdl_svc->ops)->get_endpoint(wsdl_svc, env))
+#define AXIS2_WSDL_SVC_GET_ENDPOINT(wsdl_svc, env, qname) \
+        ((wsdl_svc->ops)->get_endpoint(wsdl_svc, env, qname))
 
 #define AXIS2_WSDL_SVC_GET_NAMESPACE(wsdl_svc, env) \
         ((wsdl_svc->ops)->get_namespace(wsdl_svc, env))

Modified: webservices/axis2/trunk/c/modules/core/context/src/Makefile.am
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/Makefile.am?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/Makefile.am (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/Makefile.am Thu Dec  1 21:13:39 2005
@@ -6,4 +6,7 @@
 INCLUDES = -I${CUTEST_HOME}/include \
             -I$(top_builddir)/modules/xml/guththila/src \
             -I$(top_builddir)/include \
-            -I$(top_builddir)/modules/util/src
+            -I$(top_builddir)/modules/util/src \
+            -I$(top_builddir)/modules/wsdl/src \
+            -I$(top_builddir)/modules/core/description/src \
+            -I$(top_builddir)/modules/core/transport

Modified: webservices/axis2/trunk/c/modules/core/context/src/Makefile.in
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/Makefile.in?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/Makefile.in (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/Makefile.in Thu Dec  1 21:13:39 2005
@@ -195,7 +195,10 @@
 INCLUDES = -I${CUTEST_HOME}/include \
             -I$(top_builddir)/modules/xml/guththila/src \
             -I$(top_builddir)/include \
-            -I$(top_builddir)/modules/util/src
+            -I$(top_builddir)/modules/util/src \
+            -I$(top_builddir)/modules/wsdl/src \
+            -I$(top_builddir)/modules/core/description/src \
+            -I$(top_builddir)/modules/core/transport
 
 all: all-am
 

Modified: webservices/axis2/trunk/c/modules/core/description/src/Makefile.am
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/Makefile.am?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/description/src/Makefile.am (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/Makefile.am Thu Dec  1 21:13:39 2005
@@ -9,11 +9,14 @@
                             phase_rule.c \
                             handler_desc.c \
                             flow.c \
-                            flow_container.c
+                            flow_container.c \
+                            transport_in_desc.c \
+                            transport_out_desc.c
 
 libaxis2_description_la_LIBADD = $(LDFLAGS)
 INCLUDES = -I${CUTEST_HOME}/include -I$(top_builddir)/include \
             -I$(top_builddir)/modules/xml/guththila/src \
             -I$(top_builddir)/modules/util/src \
             -I$(top_builddir)/modules/wsdl/src \
-            -I$(top_builddir)/modules/core/transport
+            -I$(top_builddir)/modules/core/transport \
+            -I$(top_builddir)/modules/core/description

Modified: webservices/axis2/trunk/c/modules/core/description/src/Makefile.in
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/Makefile.in?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/description/src/Makefile.in (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/Makefile.in Thu Dec  1 21:13:39 2005
@@ -64,7 +64,8 @@
 libaxis2_description_la_DEPENDENCIES = $(am__DEPENDENCIES_1)
 am_libaxis2_description_la_OBJECTS = param_container.lo operation.lo \
 	svc.lo module.lo param.lo svc_grp.lo phase_rule.lo \
-	handler_desc.lo flow.lo flow_container.lo
+	handler_desc.lo flow.lo flow_container.lo transport_in_desc.lo \
+	transport_out_desc.lo
 libaxis2_description_la_OBJECTS =  \
 	$(am_libaxis2_description_la_OBJECTS)
 DEFAULT_INCLUDES = -I. -I$(srcdir) -I$(top_builddir)
@@ -201,14 +202,17 @@
                             phase_rule.c \
                             handler_desc.c \
                             flow.c \
-                            flow_container.c
+                            flow_container.c \
+                            transport_in_desc.c \
+                            transport_out_desc.c
 
 libaxis2_description_la_LIBADD = $(LDFLAGS)
 INCLUDES = -I${CUTEST_HOME}/include -I$(top_builddir)/include \
             -I$(top_builddir)/modules/xml/guththila/src \
             -I$(top_builddir)/modules/util/src \
             -I$(top_builddir)/modules/wsdl/src \
-            -I$(top_builddir)/modules/core/transport
+            -I$(top_builddir)/modules/core/transport \
+            -I$(top_builddir)/modules/core/description
 
 all: all-am
 
@@ -289,6 +293,8 @@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/phase_rule.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/svc.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/svc_grp.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/transport_in_desc.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/transport_out_desc.Plo@am__quote@
 
 .c.o:
 @am__fastdepCC_TRUE@	if $(COMPILE) -MT $@ -MD -MP -MF "$(DEPDIR)/$*.Tpo" -c -o $@ $<; \

Modified: webservices/axis2/trunk/c/modules/core/description/src/description.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/description.h?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/description/src/description.h (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/description.h Thu Dec  1 21:13:39 2005
@@ -18,7 +18,7 @@
 #define AXIS2_DESCRIPTION_H
 
 /**
- * @file axis2_description.h
+ * @file axis2_axis2_description.h
  * @brief axis2 DESCRIPTION
  */
  

Modified: webservices/axis2/trunk/c/modules/core/description/src/flow_container.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/flow_container.c?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/description/src/module_desc.c (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/module_desc.c Thu Dec  1 21:13:39 2005
@@ -45,40 +45,40 @@
                             axis2_env_t **env);
 
 axis2_flow_t *AXIS2_CALL
-axis2_module_desc_get_in_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_get_inflow(axis2_module_desc_t *module_desc,
                                     axis2_env_t **env);
 
 axis2_status_t AXIS2_CALL
-axis2_module_desc_set_in_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_set_inflow(axis2_module_desc_t *module_desc,
                                     axis2_env_t **env,
-                                    axis2_flow_t *in_flow);
+                                    axis2_flow_t *inflow);
 
 axis2_flow_t *AXIS2_CALL
-axis2_module_desc_get_out_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_get_outflow(axis2_module_desc_t *module_desc,
                                     axis2_env_t **env);
 
 axis2_status_t AXIS2_CALL
-axis2_module_desc_set_out_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_set_outflow(axis2_module_desc_t *module_desc,
                                     axis2_env_t **env,
-                                    axis2_flow_t *out_flow);
+                                    axis2_flow_t *outflow);
 
 axis2_flow_t * AXIS2_CALL
-axis2_module_desc_get_fault_in_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_get_fault_inflow(axis2_module_desc_t *module_desc,
                                         axis2_env_t **env);
 
 axis2_status_t AXIS2_CALL
-axis2_module_desc_set_fault_in_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_set_fault_inflow(axis2_module_desc_t *module_desc,
                                         axis2_env_t **env,
-                                        axis2_flow_t *falut_in_flow);
+                                        axis2_flow_t *falut_inflow);
 
 axis2_flow_t *AXIS2_CALL
-axis2_module_desc_get_fault_out_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_get_fault_outflow(axis2_module_desc_t *module_desc,
                                             axis2_env_t **env);
 
 axis2_status_t AXIS2_CALL
-axis2_module_desc_set_fault_out_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_set_fault_outflow(axis2_module_desc_t *module_desc,
                                             axis2_env_t **env,
-                                            axis2_flow_t *fault_out_flow);
+                                            axis2_flow_t *fault_outflow);
 
 axis2_qname_t * AXIS2_CALL
 axis2_module_desc_get_name (axis2_module_desc_t *module_desc,
@@ -176,22 +176,22 @@
     }
     
 	module_desc_impl->module_desc.ops->free = axis2_module_desc_free;
-    module_desc_impl->module_desc.ops->get_in_flow = axis2_module_desc_get_in_flow;
-    module_desc_impl->module_desc.ops->set_in_flow = axis2_module_desc_set_in_flow;
-    module_desc_impl->module_desc.ops->get_out_flow = axis2_module_desc_get_out_flow;
-    module_desc_impl->module_desc.ops->set_out_flow = axis2_module_desc_set_out_flow;
-    
-    module_desc_impl->module_desc.ops->get_fault_in_flow = 
-        axis2_module_desc_get_fault_in_flow;
+    module_desc_impl->module_desc.ops->get_inflow = axis2_module_desc_get_inflow;
+    module_desc_impl->module_desc.ops->set_inflow = axis2_module_desc_set_inflow;
+    module_desc_impl->module_desc.ops->get_outflow = axis2_module_desc_get_outflow;
+    module_desc_impl->module_desc.ops->set_outflow = axis2_module_desc_set_outflow;
+    
+    module_desc_impl->module_desc.ops->get_fault_inflow = 
+        axis2_module_desc_get_fault_inflow;
     
-    module_desc_impl->module_desc.ops->set_fault_in_flow = 
-        axis2_module_desc_set_fault_in_flow;
+    module_desc_impl->module_desc.ops->set_fault_inflow = 
+        axis2_module_desc_set_fault_inflow;
     
-    module_desc_impl->module_desc.ops->get_fault_out_flow = 
-        axis2_module_desc_get_fault_out_flow;
+    module_desc_impl->module_desc.ops->get_fault_outflow = 
+        axis2_module_desc_get_fault_outflow;
     
-    module_desc_impl->module_desc.ops->set_fault_out_flow = 
-        axis2_module_desc_set_fault_out_flow;
+    module_desc_impl->module_desc.ops->set_fault_outflow = 
+        axis2_module_desc_set_fault_outflow;
     
     module_desc_impl->module_desc.ops->get_name = axis2_module_desc_get_name;
     module_desc_impl->module_desc.ops->set_name = axis2_module_desc_set_name;
@@ -267,86 +267,86 @@
 }
 
 axis2_flow_t *AXIS2_CALL
-axis2_module_desc_get_in_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_get_inflow(axis2_module_desc_t *module_desc,
                                     axis2_env_t **env)
 {
     AXIS2_FUNC_PARAM_CHECK(module_desc, env, NULL);
     
-    return AXIS2_FLOW_CONTAINER_GET_IN_FLOW(module_desc->flow_container, env);
+    return AXIS2_FLOW_CONTAINER_GET_INFLOW(module_desc->flow_container, env);
 }
 
 axis2_status_t AXIS2_CALL
-axis2_module_desc_set_in_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_set_inflow(axis2_module_desc_t *module_desc,
                                     axis2_env_t **env,
-                                    axis2_flow_t *in_flow)
+                                    axis2_flow_t *inflow)
 {
     AXIS2_FUNC_PARAM_CHECK(module_desc, env, AXIS2_FAILURE);
-    AXIS2_PARAM_CHECK((*env)->error, in_flow, AXIS2_FAILURE);
+    AXIS2_PARAM_CHECK((*env)->error, inflow, AXIS2_FAILURE);
     
-    return AXIS2_FLOW_CONTAINER_SET_IN_FLOW(module_desc->flow_container, env, 
-        in_flow);    
+    return AXIS2_FLOW_CONTAINER_SET_INFLOW(module_desc->flow_container, env, 
+        inflow);    
 }
 
 axis2_flow_t *AXIS2_CALL
-axis2_module_desc_get_out_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_get_outflow(axis2_module_desc_t *module_desc,
                                     axis2_env_t **env)
 {
     AXIS2_FUNC_PARAM_CHECK(module_desc, env, NULL);
     
-    return AXIS2_FLOW_CONTAINER_GET_OUT_FLOW(module_desc->flow_container, env);
+    return AXIS2_FLOW_CONTAINER_GET_OUTFLOW(module_desc->flow_container, env);
 }
 
 axis2_status_t AXIS2_CALL
-axis2_module_desc_set_out_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_set_outflow(axis2_module_desc_t *module_desc,
                                     axis2_env_t **env,
-                                    axis2_flow_t *out_flow)
+                                    axis2_flow_t *outflow)
 {
     AXIS2_FUNC_PARAM_CHECK(module_desc, env, AXIS2_FAILURE);
-    AXIS2_PARAM_CHECK((*env)->error, out_flow, AXIS2_FAILURE);
+    AXIS2_PARAM_CHECK((*env)->error, outflow, AXIS2_FAILURE);
     
-    return AXIS2_FLOW_CONTAINER_SET_OUT_FLOW(module_desc->flow_container, env, 
-        out_flow);
+    return AXIS2_FLOW_CONTAINER_SET_OUTFLOW(module_desc->flow_container, env, 
+        outflow);
 }
 
 axis2_flow_t * AXIS2_CALL
-axis2_module_desc_get_fault_in_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_get_fault_inflow(axis2_module_desc_t *module_desc,
                                         axis2_env_t **env)
 {
     AXIS2_FUNC_PARAM_CHECK(module_desc, env, NULL);
     
-    return AXIS2_FLOW_CONTAINER_GET_FAULT_IN_FLOW(module_desc->flow_container, env);
+    return AXIS2_FLOW_CONTAINER_GET_FAULT_INFLOW(module_desc->flow_container, env);
 }
 
 axis2_status_t AXIS2_CALL
-axis2_module_desc_set_fault_in_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_set_fault_inflow(axis2_module_desc_t *module_desc,
                                         axis2_env_t **env,
-                                        axis2_flow_t *falut_in_flow)
+                                        axis2_flow_t *falut_inflow)
 {
     AXIS2_FUNC_PARAM_CHECK(module_desc, env, AXIS2_FAILURE);
-    AXIS2_PARAM_CHECK((*env)->error, falut_in_flow, AXIS2_FAILURE);
+    AXIS2_PARAM_CHECK((*env)->error, falut_inflow, AXIS2_FAILURE);
     
-    return AXIS2_FLOW_CONTAINER_SET_FAULT_IN_FLOW(module_desc->flow_container,
-        env, falut_in_flow);
+    return AXIS2_FLOW_CONTAINER_SET_FAULT_INFLOW(module_desc->flow_container,
+        env, falut_inflow);
 }
 
 axis2_flow_t *AXIS2_CALL
-axis2_module_desc_get_fault_out_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_get_fault_outflow(axis2_module_desc_t *module_desc,
                                             axis2_env_t **env)
 {
     AXIS2_FUNC_PARAM_CHECK(module_desc, env, NULL);
-    return AXIS2_FLOW_CONTAINER_GET_FAULT_OUT_FLOW(module_desc->flow_container, env);
+    return AXIS2_FLOW_CONTAINER_GET_FAULT_OUTFLOW(module_desc->flow_container, env);
 }
 
 axis2_status_t AXIS2_CALL
-axis2_module_desc_set_fault_out_flow(axis2_module_desc_t *module_desc,
+axis2_module_desc_set_fault_outflow(axis2_module_desc_t *module_desc,
                                             axis2_env_t **env,
-                                            axis2_flow_t *fault_out_flow)
+                                            axis2_flow_t *fault_outflow)
 {
     AXIS2_FUNC_PARAM_CHECK(module_desc, env, AXIS2_FAILURE);
-    AXIS2_PARAM_CHECK((*env)->error, fault_out_flow, AXIS2_FAILURE);
+    AXIS2_PARAM_CHECK((*env)->error, fault_outflow, AXIS2_FAILURE);
     
-    return AXIS2_FLOW_CONTAINER_SET_FAULT_OUT_FLOW(module_desc->flow_container, 
-        env, fault_out_flow);
+    return AXIS2_FLOW_CONTAINER_SET_FAULT_OUTFLOW(module_desc->flow_container, 
+        env, fault_outflow);
 }
 
 axis2_qname_t * AXIS2_CALL

Modified: webservices/axis2/trunk/c/modules/core/description/src/operation.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/operation.c?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/description/src/operation.c (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/operation.c Thu Dec  1 21:13:39 2005
@@ -27,8 +27,8 @@
 	struct axis2_svc *parent;
 	struct axis2_msg_recv *msg_recv;
         
-    axis2_array_list_t *remaining_phases_in_flow;
-    axis2_array_list_t *phases_out_flow;
+    axis2_array_list_t *remaining_phases_inflow;
+    axis2_array_list_t *phases_outflow;
     axis2_array_list_t *phases_in_fault_flow;
     axis2_array_list_t *phases_out_fault_flow;
     int mep;
@@ -137,12 +137,12 @@
                                             axis2_env_t **env);
 
 axis2_array_list_t * AXIS2_CALL
-axis2_operation_get_phases_out_flow(axis2_operation_t *operation,
+axis2_operation_get_phases_outflow(axis2_operation_t *operation,
                                         axis2_env_t **env);
 
 
 axis2_array_list_t *AXIS2_CALL
-axis2_operation_get_remaining_phases_in_flow(axis2_operation_t *operation,
+axis2_operation_get_remaining_phases_inflow(axis2_operation_t *operation,
                                                 axis2_env_t **env);
 
 axis2_status_t AXIS2_CALL
@@ -156,12 +156,12 @@
                                             axis2_array_list_t *list);
 
 axis2_status_t AXIS2_CALL
-axis2_operation_set_phases_out_flow(axis2_operation_t *operation,
+axis2_operation_set_phases_outflow(axis2_operation_t *operation,
                                         axis2_env_t **env,
                                         axis2_array_list_t *list);
 
 axis2_status_t AXIS2_CALL
-axis2_operation_set_remaining_phases_in_flow(axis2_operation_t *operation,
+axis2_operation_set_remaining_phases_inflow(axis2_operation_t *operation,
                                                 axis2_env_t **env,
                                                 axis2_array_list_t *list);
 
@@ -294,12 +294,12 @@
         AXIS2_ERROR_SET((*env)->error, AXIS2_ERROR_NO_MEMORY, NULL);		
 	}
 
-    operation_impl->remaining_phases_in_flow = axis2_array_list_create(env, 0);
-    if(NULL == operation_impl->remaining_phases_in_flow)
+    operation_impl->remaining_phases_inflow = axis2_array_list_create(env, 0);
+    if(NULL == operation_impl->remaining_phases_inflow)
         axis2_operation_free(&(operation_impl->operation), env);
     
-    operation_impl->phases_out_flow = axis2_array_list_create(env, 0);
-    if(NULL == operation_impl->phases_out_flow)
+    operation_impl->phases_outflow = axis2_array_list_create(env, 0);
+    if(NULL == operation_impl->phases_outflow)
         axis2_operation_free(&(operation_impl->operation), env);
     
     operation_impl->phases_in_fault_flow = axis2_array_list_create(env, 0);
@@ -353,12 +353,12 @@
     operation_impl->operation.ops->get_axis_specific_MEP_constant = axis2_operation_get_axis_specific_MEP_constant;
     operation_impl->operation.ops->get_phases_in_fault_flow = axis2_operation_get_phases_in_fault_flow;
     operation_impl->operation.ops->get_phases_out_fault_flow = axis2_operation_get_phases_out_fault_flow;
-    operation_impl->operation.ops->get_phases_out_flow = axis2_operation_get_phases_out_flow;
-    operation_impl->operation.ops->get_remaining_phases_in_flow = axis2_operation_get_remaining_phases_in_flow;
+    operation_impl->operation.ops->get_phases_outflow = axis2_operation_get_phases_outflow;
+    operation_impl->operation.ops->get_remaining_phases_inflow = axis2_operation_get_remaining_phases_inflow;
     operation_impl->operation.ops->set_phases_in_fault_flow = axis2_operation_set_phases_in_fault_flow;
     operation_impl->operation.ops->set_phases_out_fault_flow = axis2_operation_set_phases_out_fault_flow;
-    operation_impl->operation.ops->set_phases_out_flow = axis2_operation_set_phases_out_flow;
-    operation_impl->operation.ops->set_remaining_phases_in_flow = axis2_operation_set_remaining_phases_in_flow;
+    operation_impl->operation.ops->set_phases_outflow = axis2_operation_set_phases_outflow;
+    operation_impl->operation.ops->set_remaining_phases_inflow = axis2_operation_set_remaining_phases_inflow;
     operation_impl->operation.ops->add_module = axis2_operation_add_module;
     operation_impl->operation.ops->get_module_refs = axis2_operation_get_module_refs;
     operation_impl->operation.ops->get_infaults = axis2_operation_get_infaults;
@@ -465,12 +465,12 @@
     if(NULL != AXIS2_INTF_TO_IMPL(operation)->msg_recv)
 	    AXIS2_MSG_RECV_FREE(AXIS2_INTF_TO_IMPL(operation)->msg_recv, env);
     
-    if(NULL != AXIS2_INTF_TO_IMPL(operation)->remaining_phases_in_flow)
-        AXIS2_ARRAY_LIST_FREE(AXIS2_INTF_TO_IMPL(operation)->remaining_phases_in_flow,
+    if(NULL != AXIS2_INTF_TO_IMPL(operation)->remaining_phases_inflow)
+        AXIS2_ARRAY_LIST_FREE(AXIS2_INTF_TO_IMPL(operation)->remaining_phases_inflow,
             env);
     
-    if(NULL != AXIS2_INTF_TO_IMPL(operation)->phases_out_flow)
-        AXIS2_ARRAY_LIST_FREE(AXIS2_INTF_TO_IMPL(operation)->phases_out_flow,
+    if(NULL != AXIS2_INTF_TO_IMPL(operation)->phases_outflow)
+        AXIS2_ARRAY_LIST_FREE(AXIS2_INTF_TO_IMPL(operation)->phases_outflow,
             env);
     
     if(NULL != AXIS2_INTF_TO_IMPL(operation)->phases_in_fault_flow)
@@ -844,20 +844,20 @@
 
 
 axis2_array_list_t * AXIS2_CALL
-axis2_operation_get_phases_out_flow(axis2_operation_t *operation,
+axis2_operation_get_phases_outflow(axis2_operation_t *operation,
                                         axis2_env_t **env) 
 {
     AXIS2_FUNC_PARAM_CHECK(operation, env, NULL);
-    return AXIS2_INTF_TO_IMPL(operation)->phases_out_flow;
+    return AXIS2_INTF_TO_IMPL(operation)->phases_outflow;
 }
 
 
 axis2_array_list_t *AXIS2_CALL
-axis2_operation_get_remaining_phases_in_flow(axis2_operation_t *operation,
+axis2_operation_get_remaining_phases_inflow(axis2_operation_t *operation,
                                                 axis2_env_t **env) 
 {
     AXIS2_FUNC_PARAM_CHECK(operation, env, NULL);
-    return AXIS2_INTF_TO_IMPL(operation)->remaining_phases_in_flow;
+    return AXIS2_INTF_TO_IMPL(operation)->remaining_phases_inflow;
 }
 
 axis2_status_t AXIS2_CALL
@@ -891,31 +891,31 @@
 }
 
 axis2_status_t AXIS2_CALL
-axis2_operation_set_phases_out_flow(axis2_operation_t *operation,
+axis2_operation_set_phases_outflow(axis2_operation_t *operation,
                                         axis2_env_t **env,
                                         axis2_array_list_t *list) 
 {
     AXIS2_FUNC_PARAM_CHECK(operation, env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK((*env)->error, list, AXIS2_FAILURE);
     axis2_operation_impl_t *operation_impl = AXIS2_INTF_TO_IMPL(operation);
-    if(operation_impl->phases_out_flow)
-       AXIS2_WSDL_OPERATION_FREE(operation_impl->phases_out_flow, env);
+    if(operation_impl->phases_outflow)
+       AXIS2_WSDL_OPERATION_FREE(operation_impl->phases_outflow, env);
     
-    operation_impl->phases_out_flow = list;
+    operation_impl->phases_outflow = list;
     return AXIS2_SUCCESS;
 }
 
 axis2_status_t AXIS2_CALL
-axis2_operation_set_remaining_phases_in_flow(axis2_operation_t *operation,
+axis2_operation_set_remaining_phases_inflow(axis2_operation_t *operation,
                                                 axis2_env_t **env,
                                                 axis2_array_list_t *list) 
 {
     AXIS2_FUNC_PARAM_CHECK(operation, env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK((*env)->error, list, AXIS2_FAILURE);
     axis2_operation_impl_t *operation_impl = AXIS2_INTF_TO_IMPL(operation);
-    if(operation_impl->remaining_phases_in_flow)
-       AXIS2_LINKED_LIST_FREE(operation_impl->remaining_phases_in_flow, env);
-    operation_impl->remaining_phases_in_flow = list;
+    if(operation_impl->remaining_phases_inflow)
+       AXIS2_LINKED_LIST_FREE(operation_impl->remaining_phases_inflow, env);
+    operation_impl->remaining_phases_inflow = list;
     return AXIS2_SUCCESS;
 }
 

Modified: webservices/axis2/trunk/c/modules/core/description/src/phase_rule.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/phase_rule.c?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/description/src/phase_rule.c (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/phase_rule.c Thu Dec  1 21:13:39 2005
@@ -49,7 +49,7 @@
 axis2_char_t* AXIS2_CALL axis2_phase_rule_get_name (struct axis2_phase_rule * phase_rule, 
                                        axis2_env_t **env);
 axis2_status_t AXIS2_CALL axis2_phase_rule_set_name (struct axis2_phase_rule * phase_rule, 
-                                       axis2_env_t **env, axis2_char_t *name);
+                                       axis2_env_t **env, const axis2_char_t *name);
 axis2_bool_t AXIS2_CALL axis2_phase_rule_is_phase_first (struct axis2_phase_rule * phase_rule, 
                                        axis2_env_t **env);
 axis2_status_t AXIS2_CALL axis2_phase_rule_set_phase_first (struct axis2_phase_rule * phase_rule, 
@@ -193,7 +193,7 @@
 }
 
 axis2_status_t AXIS2_CALL axis2_phase_rule_set_name (struct axis2_phase_rule * phase_rule, 
-                                       axis2_env_t **env, axis2_char_t *name)
+                                       axis2_env_t **env, const axis2_char_t *name)
 {
     axis2_phase_rule_impl_t *phase_rule_impl = NULL;
--- webservices/axis2/trunk/c/modules/core/description/src/flow_container.c (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/flow_container.c Thu Dec  1 21:13:39 2005
@@ -50,40 +50,40 @@
                             axis2_env_t **env);
 
 axis2_flow_t *AXIS2_CALL
-axis2_flow_container_get_in_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_get_inflow(axis2_flow_container_t *flow_container,
                                     axis2_env_t **env);
 
 axis2_status_t AXIS2_CALL
-axis2_flow_container_set_in_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_set_inflow(axis2_flow_container_t *flow_container,
                                     axis2_env_t **env,
-                                    axis2_flow_t *in_flow);
+                                    axis2_flow_t *inflow);
 
 axis2_flow_t *AXIS2_CALL
-axis2_flow_container_get_out_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_get_outflow(axis2_flow_container_t *flow_container,
                                     axis2_env_t **env);
 
 axis2_status_t AXIS2_CALL
-axis2_flow_container_set_out_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_set_outflow(axis2_flow_container_t *flow_container,
                                     axis2_env_t **env,
-                                    axis2_flow_t *out_flow);
+                                    axis2_flow_t *outflow);
 
 axis2_flow_t * AXIS2_CALL
-axis2_flow_container_get_fault_in_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_get_fault_inflow(axis2_flow_container_t *flow_container,
                                         axis2_env_t **env);
 
 axis2_status_t AXIS2_CALL
-axis2_flow_container_set_fault_in_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_set_fault_inflow(axis2_flow_container_t *flow_container,
                                         axis2_env_t **env,
-                                        axis2_flow_t *falut_in_flow);
+                                        axis2_flow_t *falut_inflow);
 
 axis2_flow_t *AXIS2_CALL
-axis2_flow_container_get_fault_out_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_get_fault_outflow(axis2_flow_container_t *flow_container,
                                             axis2_env_t **env);
 
 axis2_status_t AXIS2_CALL
-axis2_flow_container_set_fault_out_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_set_fault_outflow(axis2_flow_container_t *flow_container,
                                             axis2_env_t **env,
-                                            axis2_flow_t *fault_out_flow);
+                                            axis2_flow_t *fault_outflow);
 
 /************************** End of function prototypes ************************/
 
@@ -109,22 +109,22 @@
     }
     
 	flow_container_impl->flow_container.ops->free =  axis2_flow_container_free;
-	flow_container_impl->flow_container.ops->get_in_flow = 
-        axis2_flow_container_get_in_flow;
-    flow_container_impl->flow_container.ops->set_in_flow = 
-        axis2_flow_container_set_in_flow;
-    flow_container_impl->flow_container.ops->get_out_flow = 
-        axis2_flow_container_get_out_flow;
-    flow_container_impl->flow_container.ops->set_out_flow = 
-        axis2_flow_container_set_out_flow;
-    flow_container_impl->flow_container.ops->get_fault_in_flow = 
-        axis2_flow_container_get_fault_in_flow;
-    flow_container_impl->flow_container.ops->set_fault_in_flow = 
-        axis2_flow_container_set_fault_in_flow;
-    flow_container_impl->flow_container.ops->get_fault_out_flow = 
-        axis2_flow_container_get_fault_out_flow;
-    flow_container_impl->flow_container.ops->set_fault_out_flow = 
-        axis2_flow_container_set_fault_out_flow;
+	flow_container_impl->flow_container.ops->get_inflow = 
+        axis2_flow_container_get_inflow;
+    flow_container_impl->flow_container.ops->set_inflow = 
+        axis2_flow_container_set_inflow;
+    flow_container_impl->flow_container.ops->get_outflow = 
+        axis2_flow_container_get_outflow;
+    flow_container_impl->flow_container.ops->set_outflow = 
+        axis2_flow_container_set_outflow;
+    flow_container_impl->flow_container.ops->get_fault_inflow = 
+        axis2_flow_container_get_fault_inflow;
+    flow_container_impl->flow_container.ops->set_fault_inflow = 
+        axis2_flow_container_set_fault_inflow;
+    flow_container_impl->flow_container.ops->get_fault_outflow = 
+        axis2_flow_container_get_fault_outflow;
+    flow_container_impl->flow_container.ops->set_fault_outflow = 
+        axis2_flow_container_set_fault_outflow;
     
     
     flow_container_impl->in = axis2_flow_create(env);
@@ -178,7 +178,7 @@
  * @return in flow
  */
 axis2_flow_t *AXIS2_CALL
-axis2_flow_container_get_in_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_get_inflow(axis2_flow_container_t *flow_container,
                                     axis2_env_t **env)
 {
     AXIS2_FUNC_PARAM_CHECK(flow_container, env, NULL);
@@ -187,15 +187,15 @@
 
 /**
  * Set in flow
- * @param in_flow in flow
+ * @param inflow in flow
  */
 axis2_status_t AXIS2_CALL
-axis2_flow_container_set_in_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_set_inflow(axis2_flow_container_t *flow_container,
                                     axis2_env_t **env,
-                                    axis2_flow_t *in_flow)
+                                    axis2_flow_t *inflow)
 {
     AXIS2_FUNC_PARAM_CHECK(flow_container, env, AXIS2_FAILURE); 
-    AXIS2_INTF_TO_IMPL(flow_container)->in = in_flow;
+    AXIS2_INTF_TO_IMPL(flow_container)->in = inflow;
     return AXIS2_SUCCESS;    
 }
 
@@ -204,7 +204,7 @@
  * @return out flow
  */
 axis2_flow_t *AXIS2_CALL
-axis2_flow_container_get_out_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_get_outflow(axis2_flow_container_t *flow_container,
                                     axis2_env_t **env)
 {
     AXIS2_FUNC_PARAM_CHECK(flow_container, env, NULL);
@@ -213,15 +213,15 @@
 
 /**
  * Set out flow
- * @param out_flow out flow
+ * @param outflow out flow
  */
 axis2_status_t AXIS2_CALL
-axis2_flow_container_set_out_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_set_outflow(axis2_flow_container_t *flow_container,
                                     axis2_env_t **env,
-                                    axis2_flow_t *out_flow)
+                                    axis2_flow_t *outflow)
 {
     AXIS2_FUNC_PARAM_CHECK(flow_container, env, AXIS2_FAILURE);
-    AXIS2_INTF_TO_IMPL(flow_container)->out = out_flow;
+    AXIS2_INTF_TO_IMPL(flow_container)->out = outflow;
     return AXIS2_SUCCESS;
 }
 
@@ -230,7 +230,7 @@
  * @return fault in flow
  */
 axis2_flow_t * AXIS2_CALL
-axis2_flow_container_get_fault_in_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_get_fault_inflow(axis2_flow_container_t *flow_container,
                                         axis2_env_t **env)
 {
     AXIS2_FUNC_PARAM_CHECK(flow_container, env, NULL);
@@ -239,15 +239,15 @@
 
 /**
  * set fault in flow
  * @param falut_in_flow falut in flow
  */
 axis2_status_t AXIS2_CALL
-axis2_flow_container_set_fault_in_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_set_fault_inflow(axis2_flow_container_t *flow_container,
                                         axis2_env_t **env,
-                                        axis2_flow_t *falut_in_flow)
+                                        axis2_flow_t *falut_inflow)
 {
     AXIS2_FUNC_PARAM_CHECK(flow_container, env, AXIS2_FAILURE);
-    AXIS2_INTF_TO_IMPL(flow_container)->in_fault = falut_in_flow;
+    AXIS2_INTF_TO_IMPL(flow_container)->in_fault = falut_inflow;
     return AXIS2_SUCCESS;
 }
 
@@ -256,7 +256,7 @@
  * @return fault out flow
  */
 axis2_flow_t *AXIS2_CALL
-axis2_flow_container_get_fault_out_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_get_fault_outflow(axis2_flow_container_t *flow_container,
                                             axis2_env_t **env)
 {
     AXIS2_FUNC_PARAM_CHECK(flow_container, env, NULL);
@@ -265,16 +265,16 @@
 
 /**
  * Set fault out flow
  * @param fault_out_flow fault out flow
  */
 axis2_status_t AXIS2_CALL
-axis2_flow_container_set_fault_out_flow(axis2_flow_container_t *flow_container,
+axis2_flow_container_set_fault_outflow(axis2_flow_container_t *flow_container,
                                             axis2_env_t **env,
-                                            axis2_flow_t *fault_out_flow)
+                                            axis2_flow_t *fault_outflow)
 {
     AXIS2_FUNC_PARAM_CHECK(flow_container, env, AXIS2_FAILURE);
-    AXIS2_PARAM_CHECK((*env)->error, fault_out_flow, AXIS2_FAILURE);
+    AXIS2_PARAM_CHECK((*env)->error, fault_outflow, AXIS2_FAILURE);
     
-    AXIS2_INTF_TO_IMPL(flow_container)->out_fault = fault_out_flow;
+    AXIS2_INTF_TO_IMPL(flow_container)->out_fault = fault_outflow;
     return AXIS2_SUCCESS;
 }
@@ -239,15 +239,15 @@
 /**
  * set fault in flow
- * @param falut_in_flow falut in flow
+ * @param falut_inflow falut in flow
  */
 axis2_status_t AXIS2_CALL
@@ -265,16 +265,16 @@
 /**
  * Set fault out flow
- * @param fault_out_flow fault out flow
+ * @param fault_outflow fault out flow
  */
 axis2_status_t AXIS2_CALL

Modified: webservices/axis2/trunk/c/modules/core/description/src/module_desc.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/module_desc.c?rev=351594&r1=351593&r2=351594&view=diff
==============================================================================